@@ -360,6 +360,32 @@ class TestRex(TestBase):
                        'BAH': 'omg',
                        'FOO': os.pathsep.join(['omg', '${BAH}', 'like']) + ', $SHE said, omg'})
 
+    def test_10(self):
+        """Test env __contains__ and __bool__"""
+
+        def _test(func, env, expected):
+            ex = self._create_executor(env=env)
+            self.assertEqual(expected, ex.execute_function(func))
+
+        def _rex_1():
+            return {
+                "A": "A" in env.keys(),
+                "B": "B" in env.keys(),
+            }
+
+        def _rex_2():
+            return {
+                "A": "A" in env,
+                "B": "B" in env,
+            }
+
+        def _rex_3():
+            return env.get("B") or "not b"
+
+        _test(_rex_1, env={"A": "foo"}, expected={"A": True, "B": False})
+        _test(_rex_2, env={"A": "foo"}, expected={"A": True, "B": False})
+        _test(_rex_3, env={}, expected="not b")
+
     def test_version_binding(self):
         """Test the Rex binding of the Version class."""
         v = VersionBinding(Version("1.2.3alpha"))
